timeviz_vnc

TimeSeries.timeviz_vnc(
    width=6,
    height=4,
    dpi=150,
    font_size=10,
    n_periods=1,
    distance='sd',
    orientation='horizontal',
    cut_line=False,
    periodize=False,
    hide_labels=False,
)

Generate a dendrogram using the clustering method, “Variability-based Neighbor Clustering”(VNC), to identify periods in the historical development of P that accounts for the temporal ordering of the data.

Parameters

Name Type Description Default
width The width of the plot. 6
height The height of the plot. 4
dpi The resolution of the plot. 150
font_size The font size for the labels. 10
n_periods The number of periods (or clusters). 1
distance One of ‘sd’ (standard deviation) or ‘cv’ (coefficient of variation). 'sd'
orientation The orientation of the plot, either ‘horizontal’ or ‘vertical’. 'horizontal'
cut_line Whether or not to include a cut line; applies only to non-periodized plots. False
periodize The dendrogram can be hard to read when the original observation matrix from which the linkage is derived is large. Periodization is used to condense the dendrogram. False
hide_labels Whether or not to hide leaf labels. False

Returns

Name Type Description
Figure A matplotlib figure.