timeviz_scatterplot
TimeSeries.timeviz_scatterplot(
width=8,
height=4,
dpi=150,
point_color='black',
point_size=0.5,
smoothing=7,
confidence_interval=True,
)
Generate a scatter plot of token frequenices over time with a smoothed fit line and a confidence interval.
Parameters
| width |
|
The width of the plot. |
8 |
| height |
|
The height of the plot. |
4 |
| dpi |
|
The resolution of the plot. |
150 |
| point_color |
|
The color of the points. |
'black' |
| point_size |
|
The size of the points. |
0.5 |
| smoothing |
|
A value between 1 and 9 specifying magnitude of smoothing. |
7 |
| confidence_interval |
|
Whether to plot a confidence interval. |
True |
Returns
|
Figure |
A matplotlib figure. |